@@ -46,7 +46,6 @@ use English; require Exporter;
 
 # Return library locations
 
-
 sub PDL_INCLUDE { '"-I'.whereami_any().'/Core"' };
 sub PDL_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
 # sub PDL_INST_INCLUDE { '-I'.whereami_any().'/Core' };
@@ -338,13 +337,17 @@ sub flushgeneric {  # Construct the generic code switch
 
 }
 
+sub _oneliner {
+  my ($cmd) = @_;
+  require ExtUtils::MM;
+  my $MM = bless { NAME => 'Fake' }, 'MM';
+  $MM->oneliner($cmd);
+}
 
 sub genpp_cmdline {
   my ($in, $out) = @_;
-  require ExtUtils::MM;
-  my $MM = bless { NAME => 'Fake' }, 'MM';
   my $devpm = whereami_any()."/Core/Dev.pm";
-  sprintf($MM->oneliner(<<'EOF'), $devpm) . qq{ "$in" > "$out"};
+  sprintf(_oneliner(<<'EOF'), $devpm) . qq{ "$in" > "$out"};
 require "%s"; PDL::Core::Dev->import(); genpp();
 EOF
 }
@@ -396,9 +399,8 @@ sub pdlpp_postamble_int {
                 $dep = $top;
                 $target = ' core';
             }
-            require ExtUtils::MM;
             $dep =~ s#([\(\)])#\\$1#g; # in case of unbalanced (
-            $depbuild .= MM->oneliner("exit(!(chdir q($dep) && !system(q(\$(MAKE)$target))))");
+            $depbuild .= _oneliner("exit(!(chdir q($dep) && !system(q(\$(MAKE)$target))))");
             $depbuild .= "\n\t";
         }
 qq|
@@ -422,6 +424,7 @@ sub pdlpp_postamble {
 	join '',map { my($src,$pref,$mod) = @$_;
 	my $w = whereami_any();
 	$w =~ s%/((PDL)|(Basic))$%%;  # remove the trailing subdir
+	my $oneliner = _oneliner(qq{exit if \$ENV{DESTDIR}; use PDL::Doc; eval { PDL::Doc::add_module(q{$mod}); }});
 qq|
 
 $pref.pm: $src
@@ -436,7 +439,7 @@ $pref\$(OBJ_EXT): $pref.c
 
 install ::
 	\@echo "Updating PDL documentation database...";
-	\$(ABSPERLRUN) -e 'exit if \$\$ENV{DESTDIR}; use PDL::Doc; eval { PDL::Doc::add_module(q{$mod}); }; ';
+	$oneliner
 |
 	} (@_)
 }
