@@ -32,7 +32,7 @@ temporary directory). For this to work you need the program ffmpeg also.
 package PDL::IO::Pic;
 
 
-@EXPORT_OK = qw( wmpeg rim wim rpic wpic rpiccan wpiccan );
+@EXPORT_OK = qw( wmpeg rim wim rpic wpic rpiccan wpiccan imageformat);
 
 %EXPORT_TAGS = (Func => [@EXPORT_OK]);
 use PDL::Core;
@@ -314,7 +314,7 @@ sub PDL::rpic {
     my $flags = $converter{$type}->{FLAGS};
     $flags = "$Dflags" unless defined($flags);
     $flags .= " $$hints{XTRAFLAGS}" if defined($$hints{XTRAFLAGS});
-    my $cmd = "$converter{$type}->{get} $flags $file |";
+    my $cmd = qq{$converter{$type}->{get} $flags "$file" |};
     $cmd = $file if $converter{$type}->{'get'} =~ /^NONE/;
 
     print("conversion by '$cmd'\n") if $PDL::IO::Pic::debug > 10;
@@ -421,7 +421,7 @@ e.g.
 =item LUT
 
 This is a palette image and the value of this key should be a
-pdl containg an RGB lookup table (3,x), e.g.
+pdl containing an RGB lookup table (3,x), e.g.
 
    LUT        => $lut,
 
@@ -490,7 +490,7 @@ sub PDL::wpic {
     ($pdl,$iform) = chkpdl($pdl,$iform,$hints,$format);
     print "using intermediate format $iform\n" if $PDL::IO::Pic::debug>10;
 
-    $cmd = "|"  . "$conv $flags >$file";
+    $cmd = "|"  . qq{$conv $flags >"$file"};
     $cmd = ">" . $file if $conv =~ /^NONE/;
     print "built the command $cmd to write image\n" if $PDL::IO::Pic::debug>10;
 
@@ -506,15 +506,15 @@ sub PDL::wpic {
 
 =for usage
 
- Usage: $a = rim($file);
- or       rim($a,$file);
+ Usage: $x = rim($file);
+ or       rim($x,$file);
 
 =for ref
 
 Read images in most formats, with improved RGB handling.
 
 You specify a filename and get back a PDL with the image data in it.
-Any PNM handled format or FITS will work. In the second form, $a is an
+Any PNM handled format or FITS will work. In the second form, $x is an
 existing PDL that gets loaded with the image data.
 
 If the image is in one of the standard RGB formats, then you get back
@@ -543,7 +543,7 @@ The same as L<rpic|rpic>, which is used as an engine:
 If you don't specify this then formats are autodetected.  If you do specify
 it then only the specified interpreter is tried.  For example,
 
-  $a = rim("foo.gif",{FORMAT=>"JPEG"})
+  $x = rim("foo.gif",{FORMAT=>"JPEG"})
 
 forces JPEG interpretation.
 
@@ -551,7 +551,7 @@ forces JPEG interpretation.
 
 Contains extra command line flags for the pnm interpreter.  For example,
 
-  $a = rim("foo.jpg",{XTRAFLAGS=>"-nolut"})
+  $x = rim("foo.jpg",{XTRAFLAGS=>"-nolut"})
 
 prevents use of a lookup table in JPEG images.
 
@@ -577,7 +577,7 @@ sub rim {
 	  ) {
 	  $out =  $out->reorder(1,2,0);
       }
-      
+
       $dest .= $out;
       return $out;
   }
@@ -704,7 +704,7 @@ is used to determine the video encoder type.
   E.g.:
     .mpg for MPEG-1 encoding
     .mp4 for MPEG-4 encoding
-   
+
   And even:
     .gif for GIF animation (uncompressed)
 
@@ -810,7 +810,35 @@ sub PDL::wmpeg {
    return 1;
 }
 
+=head2 imageformat
 
+=for ref
+
+Figure out the format of an image file from its magic numbers, or else, from its extension.
+
+Currently recognized image formats are: PNM, GIF, TIFF, JPEG, SGI,
+RAST, IFF, PCX, PS, FITS, PNG.  If the format can not be determined,
+the string 'UNKNOWN' is returned.
+
+=for example
+
+    $format=imageformat($path); # find out image format of certain file
+    print "Unknown image format" if $format eq 'UNKNOWN';
+    $canread=rpiccan($format); # check if this format is readable in this system
+    if($canread){
+        $pdl=rpic($path) ; # attempt to read image ONLY if we can
+    } else {
+        print "Image can't be read\n"; # skip unreadable file
+    }
+
+=cut
+
+sub imageformat {PDL->imageformat(@_)}
+
+sub PDL::imageformat {
+    my($class, $file)=@_;
+    return chkform($file);
+}
 
 1; # Return OK status
 
@@ -870,11 +898,14 @@ sub chkext {
     return 'UNKNOWN';
 }
 
+
+
 # try to figure out the format of a supposed image file
 # from the magic numbers (numbers taken from magic in netpbm and
 # the file format routines in xv)
 # if no magics match try extension for non-magic file types
 #     todo: make more complete
+
 sub chkform {
     my $file = shift;
     my ($format, $magic, $len, $ext) = ("","",0,"");
@@ -906,7 +937,6 @@ sub chkform {
     return chkext(getext($file));    # then try extensions
 }
 
-
 # helper proc for wpic
 # process hints for direct converter control and try to guess from extension
 # otherwise
